#
# spec file for package python-outcome
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-outcome
Version:        1.2.0
Release:        150400.9.3.9
Summary:        Function for capturing the outcome of Python function calls
License:        Apache-2.0 OR MIT
Group:          Development/Languages/Python
URL:            https://github.com/python-trio/outcome
Source:         https://github.com/python-trio/outcome/archive/v%{version}.tar.gz#/outcome-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 19.2.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module attrs >= 19.2.0}
BuildRequires:  %{python_module pytest}
%if 0%{suse_version} >= 1550 || (0%{suse_version} == 1500 && 0%{?sle_version} >= 150400)
# for more than one python 3 flavor, but no python2 flavor
BuildRequires:  %{python_module async_generator}
BuildRequires:  %{python_module pytest-asyncio}
%else
BuildRequires:  python3-async_generator
BuildRequires:  python3-pytest-asyncio
%endif
# /SECTION
%python_subpackages

%description
Outcome provides a function for capturing the outcome of a Python
function call, so that it can be passed around.

%prep
%setup -q -n outcome-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE LICENSE.APACHE2 LICENSE.MIT
%{python_sitelib}/outcome
%{python_sitelib}/outcome-%{version}*-info

%changelog
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Wed Feb  1 2023 dmueller@suse.com
- pull in dbm for all flavors on SLE15 SP4+ as well
* Tue Oct  4 2022 yarunachalam@suse.com
- Update to version 1.2.0
  * Merge pull request #33 from pquentin/spdx-compliant-license
  * Make setuptools license field SPDX-compliant
  * Merge pull request #32 from pquentin/modernize-ci
  * Use GitHub Actions and RTD CI
  * Merge pull request #30 from njsmith/release-1.1.0
* Wed Sep  1 2021 t.gruner@katodev.de
- update to version 1.1.0
  * Tweaked the implementation of Error.unwrap to avoid creating a
    reference cycle between the exception object and the unwrap
    method's frame. This shouldn't affect most users, but it
    slightly reduces the amount of work that CPython's cycle
    collector has to do, and may reduce GC pauses in some cases. (#29)
  * Drop support for Python 2.7, 3.4, and 3.5. (#27)
* Fri Dec  4 2020 code@bnavigator.de
- BuildRequire more than the default python3 flavor packages
  gh#openSUSE/python-rpm-macros#66
- pytest-cov is not required
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 1.0.1
  * Upgrade to attrs 19.2.0.
* Sun Jun  2 2019 jengelh@inai.de
- Use noun phrase in summary.
* Tue May 14 2019 tchvatal@suse.com
- Fix build for python2
- Really run tests
* Sat May 11 2019 t.gruner@katodev.de
- Initial release version 1.0.0
